set option public.Global_database_id = 0;
set option public.delete_old_logs = 'ON';


create table Admin1 (
  admin_id      bigint default global autoincrement(1000000) primary key,
  data          varchar(30),
  last_modified timestamp default timestamp
);

call ml_add_column( 'v1', 'Admin1', 'admin_id', NULL );
call ml_add_column( 'v1', 'Admin1', 'data', NULL );

create table Admin1_del (
  pk bigint default autoincrement primary key,
  admin_id bigint,
  del_time timestamp default current timestamp
);

create trigger bd_admin before delete on admin1
referencing old as pr for each row
begin
  insert into Admin1_del(admin_id) values (pr.admin_id);
end;

call ml_add_table_script( 'v1', 'Admin1', 'upload_insert', 
'insert into Admin1 values ({ml r.admin_id},{ml r.data},DEFAULT)'
);

call ml_add_table_script( 'v1', 'Admin1', 'upload_update',
'update Admin1 set data = {ml r.data} where admin_id = {ml r.admin_id}'
);

call ml_add_table_script( 'v1', 'Admin1', 'upload_delete',
'delete from Admin1 where admin_id = {ml r.admin_id}'
);

call ml_add_table_script( 'v1', 'Admin1', 'download_cursor',
'select admin_id, data from Admin1 
 where last_modified >= {ml s.last_table_download}'
);

call ml_add_table_script( 'v1', 'Admin1', 'download_delete_cursor',
'select admin_id from Admin1_del where del_time >= {ml s.last_table_download}'
);

create table Admin2 (
  admin_id      bigint default global autoincrement(1000000) primary key,
  data          varchar(30),
  last_modified timestamp default timestamp
);

call ml_add_column( 'v1', 'Admin2', 'admin_id', NULL );
call ml_add_column( 'v1', 'Admin2', 'data', NULL );

create table Admin2_del (
  pk bigint default autoincrement primary key,
  admin_id bigint,
  del_time timestamp default current timestamp
);

create trigger bd_admin before delete on admin2
referencing old as pr for each row
begin
  insert into Admin2_del(admin_id) values (pr.admin_id);
end;

call ml_add_table_script( 'v1', 'Admin2', 'upload_insert', 
'insert into Admin2 values ({ml r.admin_id},{ml r.data},DEFAULT)'
);

call ml_add_table_script( 'v1', 'Admin2', 'upload_update',
'update Admin2 set data = {ml r.data} where admin_id = {ml r.admin_id}'
);

call ml_add_table_script( 'v1', 'Admin2', 'upload_delete',
'delete from Admin2 where admin_id = {ml r.admin_id}'
);

call ml_add_table_script( 'v1', 'Admin2', 'download_cursor',
'select admin_id, data from Admin2 
 where last_modified >= {ml s.last_table_download}'
);

call ml_add_table_script( 'v1', 'Admin2', 'download_delete_cursor',
'select admin_id from Admin2_del where del_time >= {ml s.last_table_download}'
);


create table Admin3 (
  admin_id      bigint default global autoincrement(1000000) primary key,
  data          varchar(30),
  last_modified timestamp default timestamp
);

call ml_add_column( 'v1', 'Admin3', 'admin_id', NULL );
call ml_add_column( 'v1', 'Admin3', 'data', NULL );

create table Admin3_del (
  pk bigint default autoincrement primary key,
  admin_id bigint,
  del_time timestamp default current timestamp
);

create trigger bd_admin before delete on admin3
referencing old as pr for each row
begin
  insert into Admin3_del(admin_id) values (pr.admin_id);
end;

call ml_add_table_script( 'v1', 'Admin3', 'upload_insert', 
'insert into Admin3 values ({ml r.admin_id},{ml r.data},DEFAULT)'
);

call ml_add_table_script( 'v1', 'Admin3', 'upload_update',
'update Admin3 set data = {ml r.data} where admin_id = {ml r.admin_id}'
);

call ml_add_table_script( 'v1', 'Admin3', 'upload_delete',
'delete from Admin3 where admin_id = {ml r.admin_id}'
);

call ml_add_table_script( 'v1', 'Admin3', 'download_cursor',
'select admin_id, data from Admin3 
 where last_modified >= {ml s.last_table_download}'
);

call ml_add_table_script( 'v1', 'Admin3', 'download_delete_cursor',
'select admin_id from Admin3_del where del_time >= {ml s.last_table_download}'
);

create procedure ULHandleError( out action        integer,
                                in  error_code    integer,
                                in  error_message varchar(1000),
                                in  user_name     varchar(128),
                                in  table_name    varchar(128) )
begin
  if error_code = -196 or error_code = -194 then
    set action = 1000;
  else
    set action = 3000;
  end if;
end;

call ml_add_connection_script( 'v1', 'handle_error', 
'CALL ULHandleError( {ml s.action_code}, {ml s.Error_code}, 
                     {ml s.error_message}, {ml s.username}, {ml s.table} )' 
);

create procedure rep_data
   ( in iter integer default 1, 
     in do_commit integer default 0 ) 
begin
  declare j integer;
  
  set j = 0;
  while j < iter loop
    insert into admin1(data) values (cast(rand()*20 + 1 as char(10)));
    insert into admin2(data) values (cast(rand()*20 + 1 as char(10)));
    insert into admin3(data) values (cast(rand()*20 + 1 as char(10)));
    set j = j + 1;
    if do_commit = 1 then
      commit;
    end if;
  end loop;
  commit;
end;

call rep_data( 5 );
